
/******************************************/
/* API Call - Add and load accounts in    */
/* the account DB                         */
/******************************************/

function process_allocate_load_cards() {
var dateNow    = new Date();

    // Create a new XML request object
    
    var xhttp = new XMLHttpRequest();

    // Create the Allocate and Load Data Structure

    var addLoadCardData = {
        action  : "APPLY-LOAD",
        payload : 
        {
            allocateNumber : "1",
            amount         : "100",
            batchID        : "Batch_" + String( dateNow.getTime() ).substring( 4 ),
            cardMedium     : "VIRTUAL",
            currency       : "036",
            issuerID       : "Test-Issuer",
            reloadable     : "N",
        },
        sign    : ""
    };

    var theSignature = rsaSign( JSON.stringify( addLoadCardData.payload ), ISSUER_PRIVATE_KEY );

    addLoadCardData.sign = theSignature;

    // Get the data in JSON format
    
    var formattedData = JSON.stringify( addLoadCardData );
       
    //    And POST the request to OSC
 
    xhttp.open( "POST", "https://www.onlineservicescorp.com/issuer/", true );
    xhttp.setRequestHeader( "x-api-key", ISSUER_XAPI_KEY );

    /****************************************************************************/
    /*  The call back function - once request completes get the result here     */
    /****************************************************************************/
        
    xhttp.onload = function() {

        //    Get the returned data and check for success/failure

        if ( Math.floor( xhttp.status/100 ) != 2 ) 
        {
            // Set the error message
            
            var errMsg = set_server_error( xhttp );
            
           //    Allocate and Load request failed - alert the user 

            alert( "Unable to complete request.\nServer status is " + xhttp.status + " : " + errMsg + ".\n\nCheck your request accordingly" );
        } 
        else
        {
            //    Successful API call - get the data
 
            var data     = JSON.parse( this.response );
            var payLoad  = data.payload;
            var alertStr = "Message Response\n";

            //    Verify the signature

            verifySign = rsaVerify( JSON.stringify( payLoad ), OSC_PUBLIC_KEY, data.sign  );

            //  Decrypt the card data

            for( var i = 0; i < payLoad.cards.length; i++ )
            {
                payLoad.cards[i].cardData  = JSON.parse( rsaDecrypt( payLoad.cards[i].cardData, ISSUER_PRIVATE_KEY ) );

                //  Save the allocated card data

                cardList[i] = new cardAccountObj();
                cardList[i] = payLoad.cards[i];
            }

            //  Display data received

            for( var key in data.message )
                alertStr += key + "=" + data.message[key] + "\n";

            alertStr += "Payload\n";

            for( var i = 0; i < payLoad.cards.length; i++ )
            {

                alertStr += "Card Data " + i + "\n";
                for( var key in payLoad.cards[i].cardData )
                    alertStr += key + "=" + payLoad.cards[i].cardData[key] + "\n";

                delete payLoad.cards[i].cardData;

                alertStr += "Other Data " + i + "\n";
                for( var key in payLoad.cards[i] )
                    alertStr += key + "=" + payLoad.cards[i][key] + "\n";
            }

            alert( "Signature - " + verifySign + "\n" + alertStr );
        }
    }

    //    Send the request to the server 
        
    xhttp.send( formattedData );
}
