
/**********************************/
/* API Call - load a single card  */
/**********************************/

function process_list_card() {

    // Create a new XML request object
    
    var xhttp = new XMLHttpRequest();

    // Create the List Card Request data structure

    var loadCard = {
        action  : "LIST-CARD",
        payload : 
       {
            issuerID  : "Test-Issuer",
            cardToken : "SEA202503260000000",
        },
        sign    : "",
    };

    var theSignature = rsaSign( JSON.stringify( addLoadCardData.payload ), ISSUER_PRIVATE_KEY );

    loadCard.sign = theSignature;

    // Get the data in JSON format
    
    var formattedData = JSON.stringify( loadCard );
       
    //    And POST the request to OSC
 
    xhttp.open( "POST", "https://www.onlineservicescorp.com/issuer/", true );
    xhttp.setRequestHeader( "x-api-key", ISSUER_XAPI_KEY );

    /****************************************************************************/
    /*  The call back function - once request completes get the result here     */
    /****************************************************************************/
        
    xhttp.onload = function() {

        //    Get the returned data and check for success/failure

        if ( Math.floor( xhttp.status/100 ) != 2 ) 
        {
            // Set the error message
            
            var errMsg = set_server_error( xhttp );
            
           //    Get Card Account request failed - alert the user 

            alert( "Unable to complete request.\nServer status is " + xhttp.status + " : " + errMsg + ".\n\nCheck your request accordingly" );
        } 
        else
        {
            //    Successful API call - get the data
 
            var data     = JSON.parse( this.response );
            var payLoad  = data.payload;
            var alertStr = "Message Response\n";

            //    Verify the signature

            verifySign = rsaVerify( JSON.stringify( payLoad ), OSC_PUBLIC_KEY, data.sign  );

            //  Decrypt the card data

            var cData  = JSON.parse( rsaDecrypt( payLoad.cards[0].cardDetails, ISSUER_PRIVATE_KEY ) );

            payLoad.cards[0].cardDetails = cData;

            //  Display data received

            for( var key in data.message )
                alertStr += key + "=" + data.message[key] + "\n";

            alertStr += "Payload\nCard Data\n";

            for( var key in cData )
                alertStr += key + "=" + cData[key] + "\n";

            delete payLoad.cards[0].cardDetails;

            alertStr += "Other Data\n";
            
            for( var key in payLoad.cards[0] )
                alertStr += key + "=" + payLoad.cards[0][key] + "\n";

            populate_account_data( cData, payLoad.cards[0] );
            alert( "Signature - " + verifySign + "\n" + alertStr );
        }
    }

    //    Send the request to the server 
        
    xhttp.send( formattedData );
}