
/**********************************/
/* API Call - load a subset of    */
/* cards for an issuer            */
/**********************************/

function process_list_cards() {

    // Create a new XML request object
    
    var xhttp = new XMLHttpRequest();

    // Create the Load Cards Request data structure

    var loadCards = {
        action  : "LIST-CARDS",
        payload : 
       {
            dateStart : "2025-03-01",
            dateEnd   : "2025-03-02",
            issuerID  : "Test-Issuer",
        },
        sign    : "",
    };

    var theSignature = rsaSign( JSON.stringify( addLoadCardData.payload ), ISSUER_PRIVATE_KEY );

    loadCards.sign = theSignature;

    // Get the data in JSON format
    
    var formattedData = JSON.stringify( loadCards );
       
    //    And POST the request to OSC 
 
    xhttp.open( "POST", "https://www.onlineservicescorp.com/issuer/", true );
    xhttp.setRequestHeader( "x-api-key", ISSUER_XAPI_KEY );

    /****************************************************************************/
    /*  The call back function - once request completes get the result here     */
    /****************************************************************************/
        
    xhttp.onload = function() {

        //    Get the returned data and check for success/failure

        if ( Math.floor( xhttp.status/100 ) != 2 ) 
        {
            // Set the error message
            
            var errMsg = set_server_error( xhttp );
            
           //    Load accounts request failed - alert the user 

            alert( "Unable to complete request.\nServer status is " + xhttp.status + " : " + errMsg + ".\n\nCheck your request accordingly" );
        } 
        else
        {
            //    Successful API call - get the data
 
            var data     = JSON.parse( this.response );
            var payLoad  = data.payload;
            var alertStr = "Message Response\n";

            //    Verify the signature

            verifySign = rsaVerify( JSON.stringify( payLoad ), OSC_PUBLIC_KEY, data.sign  );

            //  Display data received

            for( var key in data.message )
                alertStr += key + "=" + data.message[key] + "\n";

            alertStr += "Payload\n";

            for( var i = 0; i < payLoad.cards.length; i++ )
            {
                if( payLoad.cards[i].cardDetails != undefined )
                {
                var cData = JSON.parse( rsaDecrypt( payLoad.cards[i].cardDetails, ISSUER_PRIVATE_KEY ) );

                    alertStr += "Card Details " + i + "\n";

                    for( var key in cData )
                        alertStr += key + "=" + cData[key] + "\n";

                    delete payLoad.cards[i].cardDetails;
                }

                alertStr += "Other Data " + i + "\n";

                for( var key in payLoad.cards[i] )
                    alertStr += key + "=" + payLoad.cards[i][key] + "\n";
            }

            alert( "Signature - " + verifySign + "\n" + alertStr );
        }
    }

    //    Send the request to the server 
        
    xhttp.send( formattedData );
}
