
/**********************************/
/* API Call - Get a details of a  */
/* single issuer in the system    */
/**********************************/

function process_get_issuer() {

    // Create a new XML request object
    
    var xhttp = new XMLHttpRequest();

    // Create the Get Issuer data structure

    var getIssuerData = {
        action  : "LIST-ISSUER",
        payload : 
        {
            aggregatorID : "12345678-abcd-9012-efgh-3456789abcde",
            issuerID     : "Test-Issuer",
        },
        sign    : "",
    };

    var theSignature = rsaSign( JSON.stringify( getIssuerData.payload ), ISSUER_PRIVATE_KEY );

    getIssuerData.sign = theSignature;

    // Get the data in JSON format
    
    var formattedData = JSON.stringify( getIssuerData );
       
    //    And POST the request to OSC 
 
    xhttp.open( "POST", "https://www.onlineservicescorp.com/issuer/", true );
    xhttp.setRequestHeader( "x-api-key", ISSUER_XAPI_KEY );

    /****************************************************************************/
    /*  The call back function - once request completes get the result here     */
    /****************************************************************************/
        
    xhttp.onload = function() {

        //    Get the returned data and check for success/failure

        if ( Math.floor( xhttp.status/100 ) != 2 ) 
        {
            // Set the error message
            
            var errMsg = set_server_error( xhttp );
            
           //    Get Issuer request failed - inform the user 

            alert( "Unable to complete request.\nServer status is " + xhttp.status + " : " + errMsg + ".\n\nCheck your request accordingly" );
        } 
        else
        {
            //    Successful API call - get the data
 
            var data     = JSON.parse( this.response );
            var payLoad  = data.payload;
            var alertStr = "Message Response\n";

            //    Verify the signature

            verifySign = rsaVerify( JSON.stringify( payLoad ), OSC_PUBLIC_KEY, data.sign  );

            //  Display data received

            //  The response message

            alertStr += data.message + "\n";

            //  The payload contating the issuer data

            alertStr += "Payload\n";

            //  Allocate an 'Issuer Object'

            var issuerData = new issuerObj();
            issuerData = payLoad.issuer;

            //  Display the issuer data

            for( var key in issuerData )
                alertStr += key + "=" + issuerData[key] + "\n";

            alert( "Signature - " + verifySign + "\n" + alertStr );
        }
    }

    //    Send the request to the server 
        
    xhttp.send( formattedData );
}
