
/*************************************/
/* API Call - Load card accounts     */
/*************************************/

function process_load_cards() {

    // Create the load card record data structure

    function cardData() {
		this.amount     = "";
		this.cardToken  = "";
        }

    //  Check there are card accounts allocated

    if( cardList.length == 0 )
    {
        WASP_warning( "Allocate cards before loading" )
        return false;
    }

    // Create a new XML request object
    
    var xhttp = new XMLHttpRequest();

    // Create the Load Account Data Structure

    var loadCardData = {
        action  : "LOAD",
        payload : 
        {
            currency    :   loadCurrency,
            issuerID    :   "Test-Issuer",
            cards       :   new Array(),
        },
        sign    : "",
    };

    //  Copy the card account IDs and amounts

    for( var i = 0; i < cardList.length; i++ )
    {
        loadCardData.payload.cards[i] = new cardData();

        loadCardData.payload.cards[i].amount    = cardList[i].loadAmount;
        loadCardData.payload.cards[i].cardToken = cardList[i].cardToken;
    }
          
    var theSignature = rsaSign( JSON.stringify( loadCardData.payload ), ISSUER_PRIVATE_KEY );

    loadCardData.sign = theSignature;

    // Get the data in JSON format
    
    var formattedData = JSON.stringify( loadCardData );
       
    //    And POST the request to the OSC system
 
    xhttp.open( "POST", "https://www.onlineservicescorp.com/issuer/", true );
    xhttp.setRequestHeader( "x-api-key", ISSUER_XAPI_KEY );

    /****************************************************************************/
    /*  The call back function - once request completes get the result here     */
    /****************************************************************************/
        
    xhttp.onload = function() {

        //    Get the returned data and check for success/failure

        if ( Math.floor( xhttp.status/100 ) != 2 ) 
        {
            // Set the error message
            
            var errMsg = set_server_error( xhttp );
            
           //    Load Accounts request failed - alert the user 

            alert( "Unable to complete request.\nServer status is " + xhttp.status + " : " + errMsg + ".\n\nCheck your request accordingly" );
        } 
        else
        {
            //    Successful API call - get the data
 
            var data     = JSON.parse( this.response );
            var payLoad  = data.payload;
            var alertStr = "Message Response\n";

            //    Verify the signature

            verifySign = rsaVerify( JSON.stringify( payLoad ), OSC_PUBLIC_KEY, data.sign  );

            //  Display data received

            for( var key in data.message )
                alertStr += key + "=" + data.message[key] + "\n";

            alertStr += "Payload\n";

            for( var i = 0; i < payLoad.cards.length; i++ )
            {
                alertStr += "Card Data " + i + "\n";

                for( var key in payLoad.cards[i] )
                    alertStr += key + "=" + payLoad.cards[i][key] + "\n";
            }

            alert( "Signature - " + verifySign + "\n" + alertStr );
        }
    }

    //    Send the request to the server 
        
    xhttp.send( formattedData );
}
