
/**********************************/
/* API Call - Retrieve a batch    */
/* of cards from the card DB      */
/**********************************/

function process_retrieve_batch() {

    // Create a new XML request object
    
    var xhttp = new XMLHttpRequest();

    // Retrieve Batch Request data structure

    var retrieveBatch = {
        action  : "RETRIEVE-BATCH",
        payload : 
       {
            batchID  : "Batch_975707365",
            issuerID : "Test-Issuer",
        },
        sign    : "",
    };

    var theSignature = rsaSign( JSON.stringify( addLoadCardData.payload ), ISSUER_PRIVATE_KEY );

    retrieveBatch.sign = theSignature;

    // Get the data in JSON format
    
    var formattedData = JSON.stringify( retrieveBatch );
       
    //    And POST the request to OSC
 
    xhttp.open( "POST", "https://www.onlineservicescorp.com/issuer/", true );
    xhttp.setRequestHeader( "x-api-key", ISSUER_XAPI_KEY );

    /****************************************************************************/
    /*  The call back function - once request completes get the result here     */
    /****************************************************************************/
        
    xhttp.onload = function() {

        //    Get the returned data and check for success/failure

        if ( Math.floor( xhttp.status/100 ) != 2 ) 
        {
            // Set the error message
            
            var errMsg = set_server_error( xhttp );
            
           //    Retrieve batch request failed - alert the user 

            alert( "Unable to complete request.\nServer status is " + xhttp.status + " : " + errMsg + ".\n\nCheck your request accordingly" );
        } 
        else
        {
            //    Successful API call - get the data
 
            var data     = JSON.parse( this.response );
            var payLoad  = data.payload;
            var alertStr = "Message Response\n";

            //    Verify the signature

            verifySign = verify_rsa_signature( JSON.stringify( payLoad ), data.sign, ISSUER_CRYPTO_API_URL );

            //  Display data received

            for( var key in data.message )
                alertStr += key + "=" + data.message[key] + "\n";

            //  Decrypt the card data

            for( var i = 0; i < payLoad.cards.length; i++ )
            {
                cData  = JSON.parse( decrypt_rsa_data( payLoad.cards[i].cardData, ISSUER_CRYPTO_API_URL ) );
                payLoad.cards[i].cardData = cData;
            }

            alertStr += "Payload\n";

            for( var i = 0; i < payLoad.cards.length; i++ )
            {
                alertStr += "Card Data " + i + "\n";
                for( var key in payLoad.cards[i].cardData )
                    alertStr += key + "=" + payLoad.cards[i].cardData[key] + "\n";

                delete payLoad.cards[i].cardData;

                for( var key in payLoad.cards[i] )
                    alertStr += key + "=" + payLoad.cards[i][key] + "\n";
            }

            alert( "Signature - " + verifySign + "\n" + alertStr );
        }
    }

    //    Send the request to the server 
        
    xhttp.send( formattedData );
}
