
/**********************************/
/* API Call - Update an issuer    */
/* details in the system          */
/**********************************/

function process_update_issuer() {

    // Create a new XML request object
    
    var xhttp = new XMLHttpRequest();

    // Create the Update Issuer data structure

    var updateIssuerData = {
        action  : "UPDATE-ISSUER",
        payload : 
        {
            aggregatorID : "12345678-abcd-9012-efgh-3456789abcde",
            issuerID     : "Test-Issuer",
            fields       : new issuerObj(),
        },
        sign    : "",
    };

    // Set the fields to be updated or added

    updateIssuerData.payload.fields.name      = 
    updateIssuerData.payload.fields.shortName = "New Issuer Name";

    updateIssuerData.payload.fields.address = "1 new street, new city, new country";
    updateIssuerData.payload.fields.contact = "New Issuer contact";
    updateIssuerData.payload.fields.email   = "contact@issuer.com";
    updateIssuerData.payload.fields.phone   = "135792468";

    updateIssuerData.payload.fields.url = "www.new-issuer.com";

    //  Delete the Read Only and unchanged fields

    delete updateIssuerData.payload.fields.billingCurrency;
    delete updateIssuerData.payload.fields.loadCommission;
    delete updateIssuerData.payload.fields.loadFee;
    delete updateIssuerData.payload.fields.techContact;
    delete updateIssuerData.payload.fields.techEmail;
    delete updateIssuerData.payload.fields.techPhone;
    delete updateIssuerData.payload.fields.aggregatorID;
    delete updateIssuerData.payload.fields.aggregatorName;
    delete updateIssuerData.payload.fields.parent;
    delete updateIssuerData.payload.fields.apiKey;
    delete updateIssuerData.payload.fields.balance;
    delete updateIssuerData.payload.fields.created;
    delete updateIssuerData.payload.fields.encryptPublicKey;
    delete updateIssuerData.payload.fields.lastUpdate;
    delete updateIssuerData.payload.fields.signaturePublicKey;
    delete updateIssuerData.payload.fields.status;
    delete updateIssuerData.payload.fields.statusDate;
    delete updateIssuerData.payload.fields.issuerID;

    // Create the RSA signature 

    var theSignature = rsaSign( JSON.stringify( updateIssuerData.payload ), ISSUER_PRIVATE_KEY );

    updateIssuerData.sign = theSignature;

    // Get the data in JSON format
    
    var formattedData = JSON.stringify( updateIssuerData );
       
    //    And POST the request to OSC 
 
    xhttp.open( "POST", "https://www.onlineservicescorp.com/issuer/", true );
    xhttp.setRequestHeader( "x-api-key", ADMIN_XAPI_KEY );

    /****************************************************************************/
    /*  The call back function - once request completes get the result here     */
    /****************************************************************************/
        
    xhttp.onload = function() {

        //    Get the returned data and check for success/failure

        if ( Math.floor( xhttp.status/100 ) != 2 ) 
        {
            // Set the error message
            
            var errMsg = set_server_error( xhttp );
            
           //    Update Issuer request failed - alert the user 

            alert( "Unable to complete request.\nServer status is " + xhttp.status + " : " + errMsg + ".\n\nCheck your request accordingly" );
        } 
        else
        {
            //    Successful API call - get the data
 
            var data     = JSON.parse( this.response );
            var payLoad  = data.payload;
            var alertStr = "Message Response\n";

            //    Verify the signature

            verifySign = rsaVerify( JSON.stringify( payLoad ), OSC_PUBLIC_KEY, data.sign  );

            //  Display data received

            alertStr += data.message + "\n";

            alertStr += "Payload\n";

            for( var key in payLoad.issuer )
                alertStr += key + "=" + payLoad.issuer[key] + "\n";

            alert( "Signature - " + verifySign + "\n" + alertStr );
        }
    }

    //    Send the request to the server 
        
    xhttp.send( formattedData );
}